==> digikam-3.0.0-beta3.tar.bz2: digikam-3.0.0-beta3/extra/kipi-plugins/jpeglossless/plugin/kipiplugin_jpeglossless.desktop.cmake <==
[Desktop Entry]
Name=JPEGLossless
Name[ar]=JPEG بدون ضياع
Name[ast]=JPEGLossless
Name[bg]=JPEG без загуби
Name[bs]=JPEGLossless
Name[ca]=JPEGLossless
Name[ca@valencia]=JPEGLossless
Name[cs]=JPEGLossless
Name[da]=JPEGLossless
Name[de]=Verlustfreies JPEG
Name[el]=JPEGLossless
Name[en_GB]=JPEGLossless
Name[es]=JPEG sin pérdida de calidad
Name[et]=JPEGLossless
Name[eu]=JPEGLossless
Name[fi]=Häviötön JPEG
Name[fr]=JPEGLossless
Name[ga]=JPEGLossless
Name[gl]=JPEGLossless
Name[he]=JPEG ללא אבדן
Name[hne]=जेपीईजी-लासलेस
Name[hu]=Veszteségmentes JPEG
Name[is]=JPEGtaplaust
Name[it]=JPEG senza perdita
Name[ja]=JPEGLossless
Name[km]=JPEG គ្មាន​កា​របាត់បង់
Name[ko]=JPEGLossless
Name[lv]=JPEGLossless
Name[ms]=JPEGLossless
Name[nb]=JPEGLossless
Name[nds]=JPEG ahn Verlust
Name[nl]=JPEG-lossless
Name[pa]=JPEGLossless
Name[pl]=BezstratneJPEG
Name[pt]=JPEG sem Perdas
Name[pt_BR]=JPEG sem perdas
Name[ro]=JPEG fără pierderi
Name[ru]=JPEG без потерь качества
Name[sk]=Bezstratový JPEG
Name[sl]=JPEGLossless
Name[sq]=JPEGLossless
Name[sv]=Förlustfri JPEG
Name[th]=จัดการภาพแบบ JPEGLossless
Name[tr]=Kayıpsız JPEG
Name[uk]=JPEGLossless
Name[x-test]=xxJPEGLosslessxx
Name[zh_CN]=JPEG 无损处理
Name[zh_TW]=JPEG 無損
Comment=A tool to rotate/flip images without losing quality
Comment[ast]=Una ferramienta pa rotar/voltiar imáxenes ensin perda de calidá
Comment[bg]=Инструмент за завъртане и обръщане на изображения без загуба на качество
Comment[bs]=Alat za rotiranje/okretanje slika bez gubitka kvaliteta
Comment[ca]=Una eina per a girar/voltejar imatges sense perdre qualitat
Comment[ca@valencia]=Una eina per a girar/voltejar imatges sense perdre qualitat
Comment[cs]=Nástroj na otáčení/převracení obrázků bez ztráty kvality
Comment[da]=Et værktøj til at vende/rotere billeder uden at miste kvalitet
Comment[de]=Ein Werkzeug, um Bilder ohne Verluste zu drehen und zu spiegeln.
Comment[el]=Εργαλείο περιστροφής/αναστροφής εικόνων χωρίς απώλεια ποιότητας
Comment[en_GB]=A tool to rotate/flip images without losing quality
Comment[es]=Una herramienta para rotar/invertir imágenes sin perder calidad de imagen
Comment[et]=Tööriist piltide pööramiseks ja peegeldamiseks kvaliteedis kaotamata
Comment[eu]=Irudiak galerarik gabe biratzeko/iraultzeko tresna
Comment[fi]=Kuvien kierto häviöttömästi
Comment[fr]=Outil pour retourner les images sans perte de qualité
Comment[gl]=Unha ferramenta para xirar/inverter imaxes sen perder calidade
Comment[he]=כלי לסיבוב/הפיכת תמונות שאינו מפחית את איכותן
Comment[hne]=फोटू ल बिना क्वालिटी नुकसान के घुमाय/फ्लिप करे के एक औजार
Comment[hu]=Egy eszköz képek forgatásához/tükrözéséhez minőségromlás nélkül
Comment[is]=Verkfæri til að snúa/spegla myndum án þess að tapa gæðum
Comment[it]=Uno strumento per ruotare o ribaltare immagini senza perdere in qualità
Comment[ja]=画質を落とさずに画像を回転/反転させるツール
Comment[km]=ឧបករណ៍​ត្រូវ​បង្វិល/ត្រឡប់​រូបភាព​ដោយ​​មិន​បាត់បង់​គុណភាព
Comment[lv]=Rīks attēlu pagriešanai/apmešanai bez kvalitātes zudumiem
Comment[nb]=Et verktøy for å rotere/speilvende bilder uten tap av kvalitet
Comment[nds]=En Warktüüch, mit dat sik Biller dreihen/spegeln laat, ahn dat sik de Gööd minnert
Comment[nl]=Een hulpmiddel om afbeeldingen te roteren/spiegelen zonder kwaliteit te verliezen
Comment[pl]=Narzędzie do obracania/odbijania obrazów bez utraty jakości
Comment[pt]=Uma ferramenta para rodar/inverter imagens sem perda de qualidade
Comment[pt_BR]=Uma ferramenta para rodar/inverter imagens sem perder a qualidade
Comment[ro]=O unealtă de rotit/răsturnat imagini fără pierdere în calitate
Comment[ru]=Инструмент для поворота и отражения изображений без потери качества
Comment[sk]=Nástroj na rotáciu a otočenie obrázkov bez straty kvality
Comment[sl]=Orodje za vrtenje/zrcaljenje slike brez izgube kakovosti
Comment[sq]=Një mjet për të rrotulluar/kthaer imazhet pa humbur cilësi
Comment[sv]=Ett verktyg för att rotera eller vända bilder utan att förlora kvalitet
Comment[th]=เครื่องมือในการหมุนภาพ/พลิกภาพ โดยไม่สูญเสียคุณภาพ
Comment[tr]=Resimleri kalitesini kaybetmeden döndürmek/çevirmek için bir araç
Comment[uk]=Інструмент для обертання/віддзеркалення зображень без втрати якості
Comment[x-test]=xxA tool to rotate/flip images without losing qualityxx
Comment[zh_CN]=一个不损失质量旋转/翻转图像的工具
Comment[zh_TW]=不損失品質的情形下旋轉/翻轉影像的工具
Type=Service
Icon=object-rotate-right
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_jpeglossless
author=Gilles Caulier, caulier dot gilles at gmail dot com
X-KIPI-MergeMenu=true
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
X-KIPI-PluginCategories=Image

==> digikam-4.0.0-beta3.tar.bz2: digikam-4.0.0-beta3/extra/kipi-plugins/jpeglossless/plugin/kipiplugin_jpeglossless.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=JPEGLossless
Name=JPEGLossless
Name[ar]=JPEG بدون ضياع
Name[ast]=JPEGLossless
Name[bg]=JPEG без загуби
Name[bs]=JPEGLossless
Name[ca]=JPEGLossless
Name[ca@valencia]=JPEGLossless
Name[cs]=JPEGLossless
Name[da]=JPEGLossless
Name[de]=Verlustfreies JPEG
Name[el]=JPEGLossless
Name[en_GB]=JPEGLossless
Name[es]=JPEG sin pérdida de calidad
Name[et]=JPEGLossless
Name[eu]=JPEGLossless
Name[fi]=Häviötön JPEG
Name[fr]=JPEGLossless
Name[ga]=JPEGLossless
Name[gl]=JPEGLossless
Name[he]=JPEG ללא אבדן
Name[hne]=जेपीईजी-लासलेस
Name[hu]=Veszteségmentes JPEG
Name[is]=JPEGtaplaust
Name[it]=JPEG senza perdita
Name[ja]=JPEGLossless
Name[km]=JPEG គ្មាន​កា​របាត់បង់
Name[ko]=JPEGLossless
Name[lv]=JPEGLossless
Name[ms]=JPEGLossless
Name[nb]=JPEGLossless
Name[nds]=JPEG ahn Verlust
Name[nl]=JPEG-lossless
Name[pa]=JPEGLossless
Name[pl]=BezstratneJPEG
Name[pt]=JPEG sem Perdas
Name[pt_BR]=JPEG sem perdas
Name[ro]=JPEG fără pierderi
Name[ru]=JPEG без потерь качества
Name[sk]=Bezstratový JPEG
Name[sl]=JPEGLossless
Name[sq]=JPEGLossless
Name[sv]=Förlustfri JPEG
Name[th]=จัดการภาพแบบ JPEGLossless
Name[tr]=Kayıpsız JPEG
Name[uk]=JPEGLossless
Name[x-test]=xxJPEGLosslessxx
Name[zh_CN]=JPEG 无损处理
Name[zh_TW]=JPEG 無損
Comment=A tool to rotate/flip images without losing quality
Comment[ast]=Una ferramienta pa rotar/voltiar imáxenes ensin perda de calidá
Comment[bg]=Инструмент за завъртане и обръщане на изображения без загуба на качество
Comment[bs]=Alat za rotiranje/okretanje slika bez gubitka kvaliteta
Comment[ca]=Una eina per a girar/voltejar imatges sense perdre qualitat
Comment[ca@valencia]=Una eina per a girar/voltejar imatges sense perdre qualitat
Comment[cs]=Nástroj na otáčení/převracení obrázků bez ztráty kvality
Comment[da]=Et værktøj til at vende/rotere billeder uden at miste kvalitet
Comment[de]=Ein Werkzeug, um Bilder ohne Verluste zu drehen und zu spiegeln.
Comment[el]=Εργαλείο περιστροφής/αναστροφής εικόνων χωρίς απώλεια ποιότητας
Comment[en_GB]=A tool to rotate/flip images without losing quality
Comment[es]=Una herramienta para rotar/invertir imágenes sin perder calidad de imagen
Comment[et]=Tööriist piltide pööramiseks ja peegeldamiseks kvaliteedis kaotamata
Comment[eu]=Irudiak galerarik gabe biratzeko/iraultzeko tresna
Comment[fi]=Kuvien kierto häviöttömästi
Comment[fr]=Outil pour retourner / inverser des images sans perte de qualité
Comment[gl]=Unha ferramenta para xirar/inverter imaxes sen perder calidade
Comment[he]=כלי לסיבוב/הפיכת תמונות שאינו מפחית את איכותן
Comment[hne]=फोटू ल बिना क्वालिटी नुकसान के घुमाय/फ्लिप करे के एक औजार
Comment[hu]=Egy eszköz képek forgatásához/tükrözéséhez minőségromlás nélkül
Comment[is]=Verkfæri til að snúa/spegla myndum án þess að tapa gæðum
Comment[it]=Uno strumento per ruotare o ribaltare immagini senza perdere in qualità
Comment[ja]=画質を落とさずに画像を回転/反転させるツール
Comment[km]=ឧបករណ៍​ត្រូវ​បង្វិល/ត្រឡប់​រូបភាព​ដោយ​​មិន​បាត់បង់​គុណភាព
Comment[lv]=Rīks attēlu pagriešanai/apmešanai bez kvalitātes zudumiem
Comment[nb]=Et verktøy for å rotere/speilvende bilder uten tap av kvalitet
Comment[nds]=En Warktüüch, mit dat sik Biller dreihen/spegeln laat, ahn dat sik de Gööd minnert
Comment[nl]=Een hulpmiddel om afbeeldingen te roteren/spiegelen zonder kwaliteit te verliezen
Comment[pl]=Narzędzie do obracania/odbijania obrazów bez utraty jakości
Comment[pt]=Uma ferramenta para rodar/inverter imagens sem perda de qualidade
Comment[pt_BR]=Uma ferramenta para rodar/inverter imagens sem perder a qualidade
Comment[ro]=O unealtă de rotit/răsturnat imagini fără pierdere în calitate
Comment[ru]=Инструмент для поворота и отражения изображений без потери качества
Comment[sk]=Nástroj na rotáciu a otočenie obrázkov bez straty kvality
Comment[sl]=Orodje za vrtenje/zrcaljenje slike brez izgube kakovosti
Comment[sq]=Një mjet për të rrotulluar/kthaer imazhet pa humbur cilësi
Comment[sv]=Ett verktyg för att rotera eller vända bilder utan att förlora kvalitet
Comment[th]=เครื่องมือในการหมุนภาพ/พลิกภาพ โดยไม่สูญเสียคุณภาพ
Comment[tr]=Resimleri kalitesini kaybetmeden döndürmek/çevirmek için bir araç
Comment[uk]=Інструмент для обертання/віддзеркалення зображень без втрати якості
Comment[x-test]=xxA tool to rotate/flip images without losing qualityxx
Comment[zh_CN]=一个不损失质量旋转/翻转图像的工具
Comment[zh_TW]=不損失品質的情形下旋轉/翻轉影像的工具
Type=Service
Icon=object-rotate-right
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_jpeglossless
author=Gilles Caulier, caulier dot gilles at gmail dot com
X-KIPI-MergeMenu=true
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
X-KIPI-PluginCategories=Image
